@@ -34,7 +34,7 @@ use warnings;
 
 use vars qw(@ISA @EXPORT $VERSION);
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 our $AGENT = "Mozilla/5.0 (X11; Linux x86_64; rv:80.0) Gecko/20100101 Firefox/80.0";
 our @FETCHERS = ();
 our $DEBUG = 0; # If you want debug messages, set debug to a true value, and
@@ -361,24 +361,25 @@ groundwork for this module!
 LyricFinder accepts an artist name and song title, searches supported 
 lyrics sites for song lyrics, and, if found, returns them as a string.
 
-The supported and currently-installed modules are:  L<ApiLyricsOvh>  
-(for searching api.lyrics.ovh), L<AZLyrics> (www.azlyrics.com), 
-L<Genius> (genius.com), and L<Musixmatch> (www.musixmatch.com).  There is a 
+The supported and currently-installed modules are:  
+L<LyricFinder::ApiLyricsOvh> (for searching api.lyrics.ovh), 
+L<LyricFinder::AZLyrics> (www.azlyrics.com), L<LyricFinder::Genius> 
+(genius.com), and L<LyricFinder::Musixmatch> (www.musixmatch.com).  There is a 
 special module for storing and / or fetching lyrics (.lrc) files already 
-stored locally, called L<Cache>.
+stored locally, called L<LyricFinder::Cache>.
 
 This module is derived from the (older) Lyrics::Fetcher collection of modules 
 by (c) 2007-2020 David Precious, but currently (as of December, 2020) supports 
 more lyric sites (4) and bundles all the supported site modules together here 
-(simply install this one module).  We have reworked the "Cache" module to cache 
-lyrics files by artist and song title on disk in the user's desired location.  
-LyricFinder is also truly object-oriented making interaction with the 
-user-facing methods and data easier and more streamlined.
+(simply install this one module).  We have reworked the "Cache" module to 
+cache lyrics files by artist and song title on disk in the user's desired 
+location.  LyricFinder is also truly object-oriented making interaction with 
+the user-facing methods and data easier and more streamlined.
 
 NOTE:  This module is used completely independent of any of those modules, 
 but the code is derived from them, as allowed by and the license and credits 
 are included here, as required by their open-source license.  It is capable 
-of being used as a drop-in replacement, but some function names and a few 
+of being used as a drop-in replacement, but some function names and 
 other code changes will be needed.
 
 We've also added methods to easily change the "user-agent" passed to the 
@@ -423,7 +424,7 @@ request via email or the CPAN bug system, or (for faster service), provide a
 Perl patch module / program source that can extract lyrics from that site and 
 I'll consider it!  The easiest way to do this is to take one of the existing 
 submodules, copy it to "LyricFinder::I<YOURSITE>.pm and modify it (and the POD 
-docs) to your specific site's needs, test it with sever Artist / Title 
+docs) to your specific site's needs, test it with several Artist / Title 
 combinations (see the "SYNOPSIS" code above), and send it to me 
 (That's what I do for new sites)!
 
